summaryrefslogtreecommitdiffstats
path: root/tdeui/kmenubar.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-05 23:54:16 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-05 23:54:16 -0600
commitd4e11a5f488204ab8886e167c7c4af1e6e16ab58 (patch)
tree367a2caa6169a869cfbf6395dffe2d28e0f72654 /tdeui/kmenubar.cpp
parent2c4de80e1e29b261fe8770483f97b2d702e4bd08 (diff)
downloadtdelibs-d4e11a5f488204ab8886e167c7c4af1e6e16ab58.tar.gz
tdelibs-d4e11a5f488204ab8886e167c7c4af1e6e16ab58.zip
Use non-tq sizeHint functions to fix bindings
Diffstat (limited to 'tdeui/kmenubar.cpp')
-rw-r--r--tdeui/kmenubar.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/tdeui/kmenubar.cpp b/tdeui/kmenubar.cpp
index f5d464216..b8f0f3326 100644
--- a/tdeui/kmenubar.cpp
+++ b/tdeui/kmenubar.cpp
@@ -394,7 +394,7 @@ void KMenuBar::checkSize( int& w, int& h )
{
if( !d->topLevel || d->fallback_mode )
return;
- TQSize s = tqsizeHint();
+ TQSize s = sizeHint();
w = s.width();
h = s.height();
// This is not done as setMinimumSize(), because that would set the minimum
@@ -404,17 +404,17 @@ void KMenuBar::checkSize( int& w, int& h )
h = KMAX( h, d->min_size.height());
}
-// QMenuBar's tqsizeHint() gives wrong size (insufficient width), which causes wrapping in the kicker applet
-TQSize KMenuBar::tqsizeHint() const
+// QMenuBar's sizeHint() gives wrong size (insufficient width), which causes wrapping in the kicker applet
+TQSize KMenuBar::sizeHint() const
{
if( !d->topLevel || block_resize > 0 )
- return TQMenuBar::tqsizeHint();
- // Since TQMenuBar::tqsizeHint() may indirectly call resize(),
+ return TQMenuBar::sizeHint();
+ // Since TQMenuBar::sizeHint() may indirectly call resize(),
// avoid infinite recursion.
++block_resize;
// find the minimum useful height, and enlarge the width until the menu fits in that height (one row)
int h = heightForWidth( 1000000 );
- int w = TQMenuBar::tqsizeHint().width();
+ int w = TQMenuBar::sizeHint().width();
// optimization - don't call heightForWidth() too many times
while( heightForWidth( w + 12 ) > h )
w += 12;
@@ -448,7 +448,7 @@ bool KMenuBar::x11Event( XEvent* ev )
void KMenuBar::updateMenuBarSize()
{
menuContentsChanged(); // trigger invalidating calculated size
- resize( tqsizeHint()); // and resize to preferred size
+ resize( sizeHint()); // and resize to preferred size
}
void KMenuBar::setFrameStyle( int style )